function [depth I_a] = Depth_Hallucination(path,I_d_name, I_f_name, I_c_name)
%DEPTH_HALLUCINATION performs "surface depth hallucination" based on three
%images (RAW camera file): diffuse-lit image, flash-lit image and flash
%calibration image, and finally renders a 3D view.
%
%   Diffuse-lit image(I_d_name), Flash-lit image(I_f_name) and Flash
%   calibration image(I_c_name) should be put in a same folder under
%   'path'.
%
%   Returned depth matrix(depth) and albedo map(I_a) can be used for
%   different 3D views by 'get_3Dview' function.
%   
%   EXAMPLE:
%   %Perform depth hallucination based on 'diffuse.CR2', 'flash.CR2',
%   %'calibration.CR2' which are stored in the path: D:\images
%   [depth I_a] = Depth_Hallucination('D:\images','diffuse.CR2', 'flash.CR2', 'calibration.CR2')
%
%   See also READRAW 
%
%   By Qiang Zhu @ 2008/9/12
%   qzhu@cs.ucr.edu


% Read images (RAW format) to the structure 'raws' 
raws = readraw(path,I_d_name, I_f_name, I_c_name);

% Get information (aperture,shutter speed and ISO)of images, return in the
% structure 'info'
info = get_info(); 

% Calculate 'albedo map'(I_a) and 'diffuse shading image'(I_s_nor).
[I_a I_s_nor] = get_imshade(raws,info); 

% Estimate the depth, return in the matrix 'depth' 
depth = get_depth(I_s_nor); 

% Render a full 3D view in the grid size of 2*2 pixels, without mesh lines.
% User can get a specific 3D view by setting different parameter.(see
% detaile in get_3Dview.m or type command: help get_3Dview)
get_3Dview(depth,I_a,'step',2);
