function depth = get_depth(I_s)
%GET_DEPTH estimate depth for each pixel and return a depth matrix.
%
%   The input I_s is the normalized shading image
%
%   max_blurlevel in this function is based on image content. Although the default
%   setting '5' works well in our testing, it may be specified by the user. 
%
%   See also GET_IMSHADE, GAUSSIAN_BLUR

[m n] = size(I_s);
max_blurlevel = 5; % can be specified by the user
sigma = 20;

% Calculate different levels of Gaussian blur images
I_g = zeros(m,n,max_blurlevel,'single'); 
for i = 1:max_blurlevel
    I_g(:,:,i) = Gaussian_blur(I_s,3.^(i-1),sigma);
end

% Calculate a Laplacian pyramid of equal resolution images
L = zeros(m,n,max_blurlevel-1,'single');
for i = 1:max_blurlevel-1
    L(:,:,i) = 0.5 * I_g(:,:,i+1)./I_g(:,:,i);
end

% Depth estimation (by formula 13 and 14 in the paper)
depth = zeros(m,n,'single');
for l = 1:max_blurlevel-1
    for i = 1:m
        for j = 1:n
            value = L(i,j,l);
            if value <= 0.5
                D = sqrt(1/value-1);
            else              
                D = 2 * (1 - value);
            end
            depth(i,j) = depth(i,j) + (3.^(l-1)) * (D-1);
        end
    end
end

