function [I_a I_s_nor] = get_imshade(raws, info)
%GET_IMSHADE calculates 'albedo map' and 'diffuse shading image'.
%
%   Images are stored in the structure 'raws', with their information in
%   the structure 'info'.
%   The 'albedo map' is retured in I_a and the 'diffuse shading image' in
%   I_s_nor.
%
%   See also READRAW, GET_INFO


I_f = raws.I_f;
I_d = raws.I_d;
I_c = raws.I_c;

% Calculate the exposure correction factor Ce
Ce_f = (info.I_f.A).^2 /(info.I_f.Ts * info.I_f.I);
Ce_d = (info.I_d.A).^2 /(info.I_d.Ts * info.I_d.I);
Ce_c = (info.I_c.A).^2 /(info.I_c.Ts * info.I_c.I);

% Calculate the albedo image
I_a  = (single(I_f) * Ce_f - single(I_d) * Ce_d)./(single(I_c) * Ce_c);

% Calculate the diffuse shading image
I_s = (single(I_d) / 65535 * Ce_d)./I_a;
I_s_gray = rgb2gray(uint16(I_s * 65535 /20));  
% There is a trick here. We set a magic number 20 to divide I_s, because in
% our testing I_s_gray is often too light. You might need to adjust it(to
% see I_s_gray clearly)
% Need further investigation. (If anyone find it out, or this is not true
% in your own testing, please contact me: qzhu@cs.ucr.edu. Appreciate it!)

% Normalize it
min_v = min(min(I_s_gray));
max_v = max(max(I_s_gray));
I_s_nor = single(I_s_gray - min_v)/single(max_v - min_v);
