function raws = readraw(path,I_d, I_f, I_c)
%READRAW reads three RAW format images into Matlab through Photoshop
%
%   The three images 'I_d', 'I_f' and 'I_c' should be under the same 'path'.
%
%   Current version Matlab can't read RAW camera images directly, so here
%   we read in such files throught Photoshop CS3 extended.
%   More information about communication features between MATLAB and Photoshop
%   (including setting up and connection) can be found at:
%       
%       http://livedocs.adobe.com/en_US/Photoshop/10.0/help.html?content=WS298C49A0-AC53-43c5-B19D-554CE1D87C3E.html
%
%   There are known issues when trying to launch Photoshop from MATLAB.
%   If you have multiple versions of Photoshop installed, the wrong version
%   may launch. The solution is to launch Photoshop before running any
%   MATLAB commands. On Windows, the pslaunch command will pick the last 
%   version of Photoshop that was running. Simply launch and quit the version
%   you want and pslaunch will pick that version.
%
%   NOTE:   
%        Before running this function, set Depth to 16 Bits/Channel in Workflow Options of Photoshop.


% Launch Photoshop
pslaunch;

% Setting the full path for three image files
path_I_d = [path '\' I_d];
path_I_f = [path '\' I_f];
path_I_c = [path '\' I_c];

% Read images into 'raws'
raws = struct;
raws.I_d = psimread(path_I_d);
[W, H, R, N, M, B] = psdocinfo();
if B~=16    % Check whether 'Bits Per Channel' is set to 16
    disp('Error: Please set Bits Per Channel to 16 in Photoshop.');
    return;
end
raws.I_f = psimread(path_I_f);
raws.I_c = psimread(path_I_c);
